Tutorial
========

**TODO:**

* adding/removing repos
* creating a HOMELY.py script
* basic symlinks
* modifying files with lineinfile/blockinfile
* installing packages with yum/brew/apt
* homely update
* cleanup
